package org.jeecg.modules.orderplatform.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.orderplatform.entity.PlatformScript;
import org.jeecg.modules.orderplatform.service.IPlatformScriptService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

/**
 * 下单平台关联脚本
 */
@Slf4j
@RestController
@RequestMapping("/com.cn/platformScript")
public class PlatformScriptController {
	@Autowired
	private IPlatformScriptService platformScriptService;

	/**
	 * 分页列表查询
	 */
	@GetMapping(value = "/list")
	public Result<IPage<PlatformScript>> queryPageList(PlatformScript platformScript,
													   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
													   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
													   HttpServletRequest req) {
		Result<IPage<PlatformScript>> result = new Result<>();
		QueryWrapper<PlatformScript> queryWrapper = QueryGenerator.initQueryWrapper(platformScript, req.getParameterMap());
		Page<PlatformScript> page = new Page<>(pageNo, pageSize);
		IPage<PlatformScript> pageList = platformScriptService.page(page, queryWrapper);
		result.setSuccess(true);
		result.setResult(pageList);
		return result;
	}

	/**
	 *   添加
	 */
	@PostMapping(value = "/add")
	public Result<PlatformScript> add(@RequestBody PlatformScript platformScript) {
		Result<PlatformScript> result = new Result<>();
		try {
			platformScriptService.save(platformScript);
			result.success("添加成功！");
		} catch (Exception e) {
			log.error(e.getMessage(),e);
			result.error500("操作失败");
		}
		return result;
	}

	/**
	 *  编辑
	 */
	@PostMapping(value = "/edit")
	public Result<PlatformScript> edit(@RequestBody PlatformScript platformScript) {
		Result<PlatformScript> result = new Result<PlatformScript>();
		PlatformScript platformScriptEntity = platformScriptService.getById(platformScript.getId());
		if(platformScriptEntity==null) {
			result.error500("未找到对应实体");
		}else {
			boolean ok = platformScriptService.updateById(platformScript);
			if(ok) {
				result.success("修改成功!");
			}
		}

		return result;
	}

	/**
	 * 通过id删除
	 */
	@PostMapping(value = "/delete")
	public Result<?> delete(@RequestParam(name="id",required=true) String id) {
		try {
			platformScriptService.removeById(id);
		} catch (Exception e) {
			log.error("删除失败",e.getMessage());
			return Result.error("删除失败!");
		}
		return Result.ok("删除成功!");
	}

	/**
	 *  批量删除
	 */
	@PostMapping(value = "/deleteBatch")
	public Result<PlatformScript> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		Result<PlatformScript> result = new Result<>();
		if(ids==null || "".equals(ids.trim())) {
			result.error500("参数不识别！");
		}else {
			this.platformScriptService.removeByIds(Arrays.asList(ids.split(",")));
			result.success("删除成功!");
		}
		return result;
	}

	/**
	 * 通过id查询
	 */
	@GetMapping(value = "/queryById")
	public Result<PlatformScript> queryById(@RequestParam(name="id",required=true) String id) {
		Result<PlatformScript> result = new Result<>();
		PlatformScript platformScript = platformScriptService.getById(id);
		if(platformScript==null) {
			result.error500("未找到对应实体");
		}else {
			result.setResult(platformScript);
			result.setSuccess(true);
		}
		return result;
	}

}
